@@ -1,7 +1,8 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
- * 
+ *
  * Copyright 2000, 2010 Oracle and/or its affiliates.
  *
  * OpenOffice.org - a multi-platform office productivity suite
@@ -38,11 +39,9 @@
 #include "dlgedview.hxx"
 #include "dlgedlist.hxx"
 #include <iderid.hxx>
-#include <localizationmgr.hxx> 
+#include <localizationmgr.hxx>
 
-#ifndef _BASCTL_DLGRESID_HRC
 #include <dlgresid.hrc>
-#endif
 #include <tools/resmgr.hxx>
 #include <tools/shl.hxx>
 #include <unotools/sharedunocomponent.hxx>
@@ -85,7 +84,7 @@ DlgEdObj::DlgEdObj()
 
 //----------------------------------------------------------------------------
 
-DlgEdObj::DlgEdObj(const ::rtl::OUString& rModelName, 
+DlgEdObj::DlgEdObj(const ::rtl::OUString& rModelName,
                    const com::sun::star::uno::Reference< com::sun::star::lang::XMultiServiceFactory >& rxSFac)
           :SdrUnoObj(rModelName, rxSFac, sal_False)
           ,bIsListening(sal_False)
@@ -151,8 +150,8 @@ uno::Reference< awt::XControl > DlgEdObj::GetControl() const
 
 //----------------------------------------------------------------------------
 
-bool DlgEdObj::TransformSdrToControlCoordinates( 
-    sal_Int32 nXIn, sal_Int32 nYIn, sal_Int32 nWidthIn, sal_Int32 nHeightIn, 
+bool DlgEdObj::TransformSdrToControlCoordinates(
+    sal_Int32 nXIn, sal_Int32 nYIn, sal_Int32 nWidthIn, sal_Int32 nHeightIn,
     sal_Int32& nXOut, sal_Int32& nYOut, sal_Int32& nWidthOut, sal_Int32& nHeightOut )
 {
     // input position and size
@@ -192,10 +191,10 @@ bool DlgEdObj::TransformSdrToControlCoordinates(
         aPos.Width() -= aDeviceInfo.LeftInset;
         aPos.Height() -= aDeviceInfo.TopInset;
     }
-    
+
     // convert pixel to logic units
-    aPos = pDevice->PixelToLogic( aPos, MapMode( MAP_APPFONT ) );
-    aSize = pDevice->PixelToLogic( aSize, MapMode( MAP_APPFONT ) );
+    aPos = pDevice->PixelToLogic( aPos, MAP_APPFONT );
+    aSize = pDevice->PixelToLogic( aSize, MAP_APPFONT );
 
     // set out parameters
     nXOut = aPos.Width();
@@ -208,8 +207,8 @@ bool DlgEdObj::TransformSdrToControlCoordinates(
 
 //----------------------------------------------------------------------------
 
-bool DlgEdObj::TransformSdrToFormCoordinates( 
-    sal_Int32 nXIn, sal_Int32 nYIn, sal_Int32 nWidthIn, sal_Int32 nHeightIn, 
+bool DlgEdObj::TransformSdrToFormCoordinates(
+    sal_Int32 nXIn, sal_Int32 nYIn, sal_Int32 nWidthIn, sal_Int32 nHeightIn,
     sal_Int32& nXOut, sal_Int32& nYOut, sal_Int32& nWidthOut, sal_Int32& nHeightOut )
 {
     // input position and size
@@ -242,10 +241,9 @@ bool DlgEdObj::TransformSdrToFormCoordinates(
         aSize.Width() -= aDeviceInfo.LeftInset + aDeviceInfo.RightInset;
         aSize.Height() -= aDeviceInfo.TopInset + aDeviceInfo.BottomInset;
     }
-
     // convert pixel to logic units
-    aPos = pDevice->PixelToLogic( aPos, MapMode( MAP_APPFONT ) );
-    aSize = pDevice->PixelToLogic( aSize, MapMode( MAP_APPFONT ) );
+    aPos = pDevice->PixelToLogic( aPos, MAP_APPFONT );
+    aSize = pDevice->PixelToLogic( aSize, MAP_APPFONT );
 
     // set out parameters
     nXOut = aPos.Width();
@@ -258,8 +256,8 @@ bool DlgEdObj::TransformSdrToFormCoordinates(
 
 //----------------------------------------------------------------------------
 
-bool DlgEdObj::TransformControlToSdrCoordinates( 
-    sal_Int32 nXIn, sal_Int32 nYIn, sal_Int32 nWidthIn, sal_Int32 nHeightIn, 
+bool DlgEdObj::TransformControlToSdrCoordinates(
+    sal_Int32 nXIn, sal_Int32 nYIn, sal_Int32 nWidthIn, sal_Int32 nHeightIn,
     sal_Int32& nXOut, sal_Int32& nYOut, sal_Int32& nWidthOut, sal_Int32& nHeightOut )
 {
     // input position and size
@@ -287,9 +285,9 @@ bool DlgEdObj::TransformControlToSdrCoordinates(
     DBG_ASSERT( pDevice, "DlgEdObj::TransformControlToSdrCoordinates: missing default device!" );
     if ( !pDevice )
         return false;
-    aPos = pDevice->LogicToPixel( aPos, MapMode( MAP_APPFONT ) );
-    aSize = pDevice->LogicToPixel( aSize, MapMode( MAP_APPFONT ) );
-    aFormPos = pDevice->LogicToPixel( aFormPos, MapMode( MAP_APPFONT ) );
+    aPos = pDevice->LogicToPixel( aPos, MAP_APPFONT );
+    aSize = pDevice->LogicToPixel( aSize, MAP_APPFONT );
+    aFormPos = pDevice->LogicToPixel( aFormPos, MAP_APPFONT );
 
     // add form position
     aPos.Width() += aFormPos.Width();
@@ -320,8 +318,8 @@ bool DlgEdObj::TransformControlToSdrCoordinates(
 
 //----------------------------------------------------------------------------
 
-bool DlgEdObj::TransformFormToSdrCoordinates( 
-    sal_Int32 nXIn, sal_Int32 nYIn, sal_Int32 nWidthIn, sal_Int32 nHeightIn, 
+bool DlgEdObj::TransformFormToSdrCoordinates(
+    sal_Int32 nXIn, sal_Int32 nYIn, sal_Int32 nWidthIn, sal_Int32 nHeightIn,
     sal_Int32& nXOut, sal_Int32& nYOut, sal_Int32& nWidthOut, sal_Int32& nHeightOut )
 {
     // input position and size
@@ -333,14 +331,15 @@ bool DlgEdObj::TransformFormToSdrCoordinates(
     DBG_ASSERT( pDevice, "DlgEdObj::TransformFormToSdrCoordinates: missing default device!" );
     if ( !pDevice )
         return false;
-    aPos = pDevice->LogicToPixel( aPos, MapMode( MAP_APPFONT ) );
-    aSize = pDevice->LogicToPixel( aSize, MapMode( MAP_APPFONT ) );
 
     // take window borders into account
     DlgEdForm* pForm = NULL;
     if ( !lcl_getDlgEdForm( this, pForm ) )
         return false;
 
+    aPos = pDevice->LogicToPixel( aPos, MAP_APPFONT );
+    aSize = pDevice->LogicToPixel( aSize, MAP_APPFONT );
+
     // take window borders into account
     Reference< beans::XPropertySet > xPSetForm( pForm->GetUnoControlModel(), UNO_QUERY );
     DBG_ASSERT( xPSetForm.is(), "DlgEdObj::TransformFormToSdrCoordinates: no form property set!" );
@@ -375,7 +374,7 @@ void DlgEdObj::SetRectFromProps()
     // get control position and size from properties
     Reference< beans::XPropertySet > xPSet( GetUnoControlModel(), UNO_QUERY );
     if ( xPSet.is() )
-    {		
+    {
         sal_Int32 nXIn = 0, nYIn = 0, nWidthIn = 0, nHeightIn = 0;
         xPSet->getPropertyValue( DLGED_PROP_POSITIONX ) >>= nXIn;
         xPSet->getPropertyValue( DLGED_PROP_POSITIONY ) >>= nYIn;
@@ -450,7 +449,7 @@ void DlgEdObj::PositionAndSizeChange( const beans::PropertyChangeEvent& evt )
         {
             Reference< beans::XPropertySet > xPSet( GetUnoControlModel(), UNO_QUERY );
             if ( xPSet.is() )
-            {		
+            {
                 sal_Int32 nX = 0, nY = 0, nWidth = 0, nHeight = 0;
                 xPSet->getPropertyValue( DLGED_PROP_POSITIONX ) >>= nX;
                 xPSet->getPropertyValue( DLGED_PROP_POSITIONY ) >>= nY;
@@ -501,7 +500,7 @@ void DlgEdObj::PositionAndSizeChange( const beans::PropertyChangeEvent& evt )
             }
         }
     }
-    
+
     SetRectFromProps();
 }
 
@@ -521,10 +520,10 @@ void SAL_CALL DlgEdObj::NameChange( const  ::com::sun::star::beans::PropertyChan
     {
         Reference< container::XNameAccess > xNameAcc((GetDlgEdForm()->GetUnoControlModel()), UNO_QUERY);
         if ( xNameAcc.is() && xNameAcc->hasByName(aOldName) )
-        {	
+        {
             if ( !xNameAcc->hasByName(aNewName) && aNewName.getLength() != 0 )
             {
-                // remove the control by the old name and insert the control by the new name in the container 
+                // remove the control by the old name and insert the control by the new name in the container
                 Reference< container::XNameContainer > xCont(xNameAcc, UNO_QUERY );
                 if ( xCont.is() )
                 {
@@ -540,7 +539,7 @@ void SAL_CALL DlgEdObj::NameChange( const  ::com::sun::star::beans::PropertyChan
                     else
                         pEditor = GetDlgEdForm()->GetDlgEditor();
                     LocalizationMgr::renameControlResourceIDsForEditorObject( pEditor, aAny, aNewName );
-                }		
+                }
             }
             else
             {
@@ -712,9 +711,9 @@ sal_Bool DlgEdObj::supportsService( const sal_Char* _pServiceName ) const
 //----------------------------------------------------------------------------
 
 ::rtl::OUString DlgEdObj::GetDefaultName() const
-{	
+{
     sal_uInt16 nResId = 0;
-    ::rtl::OUString aDefaultName;	
+    ::rtl::OUString aDefaultName;
     if ( supportsService( "com.sun.star.awt.UnoControlDialogModel" ) )
     {
         nResId = RID_STR_CLASS_DIALOG;
@@ -802,12 +801,12 @@ sal_Bool DlgEdObj::supportsService( const sal_Char* _pServiceName ) const
 
     else
     {
-        nResId = RID_STR_CLASS_CONTROL;        
+        nResId = RID_STR_CLASS_CONTROL;
     }
 
     if (nResId)
     {
-        aDefaultName = ::rtl::OUString( String(IDEResId(nResId)) );			
+        aDefaultName = ::rtl::OUString( String(IDEResId(nResId)) );
     }
 
     return aDefaultName;
@@ -1016,11 +1015,11 @@ void DlgEdObj::operator= (const SdrObject& rObj)
 void DlgEdObj::NbcMove( const Size& rSize )
 {
     SdrUnoObj::NbcMove( rSize );
-    
+
     // stop listening
     EndListening(sal_False);
-    
-    // set geometry properties	
+
+    // set geometry properties
     SetPropsFromRect();
 
     // start listening
@@ -1038,8 +1037,8 @@ void DlgEdObj::NbcResize(const Point& rRef, const Fraction& xFract, const Fracti
 
     // stop listening
     EndListening(sal_False);
-    
-    // set geometry properties	
+
+    // set geometry properties
     SetPropsFromRect();
 
     // start listening
@@ -1051,9 +1050,9 @@ void DlgEdObj::NbcResize(const Point& rRef, const Fraction& xFract, const Fracti
 
 //----------------------------------------------------------------------------
 
-FASTBOOL DlgEdObj::EndCreate(SdrDragStat& rStat, SdrCreateCmd eCmd)
+bool DlgEdObj::EndCreate(SdrDragStat& rStat, SdrCreateCmd eCmd)
 {
-    FASTBOOL bResult = SdrUnoObj::EndCreate(rStat, eCmd);
+    bool bResult = SdrUnoObj::EndCreate(rStat, eCmd);
 
     SetDefaults();
     StartListening();
@@ -1084,7 +1083,7 @@ void DlgEdObj::SetDefaults()
             aUniqueName <<= aOUniqueName;
             xPSet->setPropertyValue( DLGED_PROP_NAME, aUniqueName );
 
-            // set labels	
+            // set labels
             if ( supportsService( "com.sun.star.awt.UnoControlButtonModel" ) ||
                 supportsService( "com.sun.star.awt.UnoControlRadioButtonModel" ) ||
                 supportsService( "com.sun.star.awt.UnoControlCheckBoxModel" ) ||
@@ -1144,7 +1143,7 @@ void DlgEdObj::SetDefaults()
             }
         }
 
-        // dialog model changed 
+        // dialog model changed
         pDlgEdForm->GetDlgEditor()->SetDialogModelChanged( TRUE );
     }
 }
@@ -1170,13 +1169,13 @@ void DlgEdObj::StartListening()
     if (!isListening())
     {
         bIsListening = sal_True;
-        
+
         // XPropertyChangeListener
         Reference< XPropertySet > xControlModel( GetUnoControlModel() , UNO_QUERY );
         if (!m_xPropertyChangeListener.is() && xControlModel.is())
         {
             // create listener
-            m_xPropertyChangeListener = static_cast< ::com::sun::star::beans::XPropertyChangeListener*>( new DlgEdPropListenerImpl( (DlgEdObj*)this ) );	
+            m_xPropertyChangeListener = static_cast< ::com::sun::star::beans::XPropertyChangeListener*>( new DlgEdPropListenerImpl( (DlgEdObj*)this ) );
 
             // register listener to properties
             xControlModel->addPropertyChangeListener( ::rtl::OUString() , m_xPropertyChangeListener );
@@ -1187,9 +1186,9 @@ void DlgEdObj::StartListening()
         if( !m_xContainerListener.is() && xEventsSupplier.is() )
         {
             // create listener
-            m_xContainerListener = static_cast< ::com::sun::star::container::XContainerListener*>( new DlgEdEvtContListenerImpl( (DlgEdObj*)this ) );	
+            m_xContainerListener = static_cast< ::com::sun::star::container::XContainerListener*>( new DlgEdEvtContListenerImpl( (DlgEdObj*)this ) );
 
-            // register listener to script event container			
+            // register listener to script event container
             Reference< XNameContainer > xEventCont = xEventsSupplier->getEvents();
             DBG_ASSERT(xEventCont.is(), "DlgEdObj::StartListening: control model has no script event container!");
             Reference< XContainer > xCont( xEventCont , UNO_QUERY );
@@ -1253,7 +1252,7 @@ void SAL_CALL DlgEdObj::_propertyChange( const  ::com::sun::star::beans::Propert
 
         // dialog model changed
         pDlgEditor->SetDialogModelChanged(TRUE);
-        
+
         // update position and size
         if ( evt.PropertyName == DLGED_PROP_POSITIONX || evt.PropertyName == DLGED_PROP_POSITIONY ||
              evt.PropertyName == DLGED_PROP_WIDTH || evt.PropertyName == DLGED_PROP_HEIGHT ||
@@ -1404,7 +1403,7 @@ void DlgEdForm::SetRectFromProps()
     // get form position and size from properties
     Reference< beans::XPropertySet > xPSet( GetUnoControlModel(), UNO_QUERY );
     if ( xPSet.is() )
-    {		
+    {
         sal_Int32 nXIn = 0, nYIn = 0, nWidthIn = 0, nHeightIn = 0;
         xPSet->getPropertyValue( DLGED_PROP_POSITIONX ) >>= nXIn;
         xPSet->getPropertyValue( DLGED_PROP_POSITIONY ) >>= nYIn;
@@ -1475,8 +1474,8 @@ void DlgEdForm::PositionAndSizeChange( const beans::PropertyChangeEvent& evt )
 {
     DlgEditor* pEditor = GetDlgEditor();
     DBG_ASSERT( pEditor, "DlgEdForm::PositionAndSizeChange: no dialog editor!" );
-    if ( pEditor )    
-    {    
+    if ( pEditor )
+    {
         DlgEdPage* pPage_ = pEditor->GetPage();
         DBG_ASSERT( pPage_, "DlgEdForm::PositionAndSizeChange: no page!" );
         if ( pPage_ )
@@ -1545,7 +1544,7 @@ void DlgEdForm::PositionAndSizeChange( const beans::PropertyChangeEvent& evt )
                     {
                         Reference< beans::XPropertySet > xPSet( (*aIter)->GetUnoControlModel(), UNO_QUERY );
                         if ( xPSet.is() )
-                        {		
+                        {
                             sal_Int32 nX = 0, nY = 0, nWidth = 0, nHeight = 0;
                             xPSet->getPropertyValue( DLGED_PROP_POSITIONX ) >>= nX;
                             xPSet->getPropertyValue( DLGED_PROP_POSITIONY ) >>= nY;
@@ -1618,7 +1617,7 @@ void DlgEdForm::UpdateStep()
 //----------------------------------------------------------------------------
 
 void DlgEdForm::UpdateTabIndices()
-{	
+{
     // stop listening with all children
     ::std::vector<DlgEdObj*>::iterator aIter;
     for ( aIter = pChilds.begin() ; aIter != pChilds.end() ; ++aIter )
@@ -1686,7 +1685,7 @@ void DlgEdForm::UpdateTabOrder()
     // #110559#
     // When the tabindex of a control model changes, the dialog control is
     // notified about those changes. Due to #109067# (bad performance of
-    // dialog editor) the dialog control doesn't activate the tab order 
+    // dialog editor) the dialog control doesn't activate the tab order
     // in design mode. When the dialog editor has reordered all
     // tabindices, this method allows to activate the taborder afterwards.
 
@@ -1708,10 +1707,10 @@ void DlgEdForm::UpdateGroups()
     // #110559#
     // The grouping of radio buttons in a dialog is done by vcl.
     // In the dialog editor we have two views (=controls) for one
-    // radio button model. One control is owned by the dialog control, 
+    // radio button model. One control is owned by the dialog control,
     // but not visible in design mode. The other control is owned by
     // the drawing layer object. Whereas the grouping of the first
-    // control is done by vcl, the grouping of the control in the 
+    // control is done by vcl, the grouping of the control in the
     // drawing layer has to be done here.
 
     Reference< awt::XTabControllerModel > xTabModel( GetUnoControlModel() , UNO_QUERY );
@@ -1746,21 +1745,21 @@ void DlgEdForm::UpdateGroups()
                     const Reference< awt::XControl > xCtrl( pControls[nControl] );
                     if ( xCtrl.is() )
                     {
-                        Reference< awt::XControlModel > xCtrlModel( xCtrl->getModel() );                            
+                        Reference< awt::XControlModel > xCtrlModel( xCtrl->getModel() );
                         if ( (awt::XControlModel*)xCtrlModel.get() == (awt::XControlModel*)pModels[nModel].get() )
                         {
                             // get the control peer and insert into the list of peers
                             aSeqPeers.getArray()[ nModel ] = Reference< awt::XWindow >( xCtrl->getPeer(), UNO_QUERY );
                             break;
                         }
-                    }                       
+                    }
                 }
             }
 
             // set the group at the dialog peer
             Reference< awt::XControl > xDlg( GetControl(), UNO_QUERY );
             if ( xDlg.is() )
-            {                    
+            {
                 Reference< awt::XVclContainerPeer > xDlgPeer( xDlg->getPeer(), UNO_QUERY );
                 if ( xDlgPeer.is() )
                     xDlgPeer->setGroup( aSeqPeers );
@@ -1782,7 +1781,7 @@ void DlgEdForm::UpdateTabOrderAndGroups()
 void DlgEdForm::NbcMove( const Size& rSize )
 {
     SdrUnoObj::NbcMove( rSize );
-    
+
     // set geometry properties of form
     EndListening(sal_False);
     SetPropsFromRect();
@@ -1827,9 +1826,9 @@ void DlgEdForm::NbcResize(const Point& rRef, const Fraction& xFract, const Fract
 
 //----------------------------------------------------------------------------
 
-FASTBOOL DlgEdForm::EndCreate(SdrDragStat& rStat, SdrCreateCmd eCmd)
+bool DlgEdForm::EndCreate(SdrDragStat& rStat, SdrCreateCmd eCmd)
 {
-    FASTBOOL bResult = SdrUnoObj::EndCreate(rStat, eCmd);
+    bool bResult = SdrUnoObj::EndCreate(rStat, eCmd);
 
     // stop listening
     EndListening(sal_False);
@@ -1837,7 +1836,7 @@ FASTBOOL DlgEdForm::EndCreate(SdrDragStat& rStat, SdrCreateCmd eCmd)
     // set geometry properties
     SetPropsFromRect();
 
-    // dialog model changed 
+    // dialog model changed
     GetDlgEditor()->SetDialogModelChanged(TRUE);
 
     // start listening
@@ -1894,3 +1893,4 @@ awt::DeviceInfo DlgEdForm::getDeviceInfo() const
 //----------------------------------------------------------------------------
 
 
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
