@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -40,9 +41,7 @@
 #include <Windows.h>
 #include <com/sun/star/lang/SystemDependent.hpp>
 #include <com/sun/star/awt/XSystemChildFactory.hpp>
-#ifndef _COM_SUN_STAR_AWT_XSYSTEMDEPENDENTWINDOWPERR_HPP_
 #include <com/sun/star/awt/XSystemDependentWindowPeer.hpp>
-#endif
 #include <com/sun/star/awt/XSystemDependentMenuPeer.hpp>
 #include <com/sun/star/ui/XUIElement.hpp>
 #include <com/sun/star/awt/WindowAttribute.hpp>
@@ -51,9 +50,7 @@
 #include <com/sun/star/lang/XMultiServiceFactory.hpp>
 #include <com/sun/star/util/XCloseBroadcaster.hpp>
 #include <com/sun/star/util/XCloseAble.hpp>
-#ifndef _COM_SUN_STAR_CONTAINER_XNAMEACESS_HPP_
 #include <com/sun/star/container/XNameAccess.hpp>
-#endif
 #include <com/sun/star/beans/XPropertySet.hpp>
 #include <com/sun/star/frame/XModel.hpp>
 #include <com/sun/star/frame/XDesktop.hpp>
@@ -1644,3 +1641,5 @@ void SAL_CALL DocumentHolder::modified( const lang::EventObject& /*aEvent*/ )
 #if defined(_MSC_VER)
 #pragma warning(disable: 4505)
 #endif
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
