@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -43,19 +44,13 @@
 #include <com/sun/star/util/Time.hpp>
 #include <comphelper/sequence.hxx>
 #include <connectivity/dbconversion.hxx>
-#ifndef _EXTENSIONS_PROPCTRLR_MODULEPRC_HXX_
 #include "modulepcr.hxx"
-#endif
-#ifndef _EXTENSIONS_FORMCTRLR_PROPRESID_HRC_
 #include "formresid.hrc"
-#endif
 #include <tools/debug.hxx>
 #include <tools/string.hxx>
 #include <tools/StringListResource.hxx>
 #include <comphelper/types.hxx>
-#ifndef _EXTENSIONS_PROPCTRLR_MODULEPCR_HXX_
 #include "modulepcr.hxx"
-#endif
 
 #include <functional>
 #include <algorithm>
@@ -648,3 +643,4 @@ extern "C" void SAL_CALL createRegistryInfo_StringRepresentation()
         );
 }
 
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
