@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -40,9 +41,7 @@
 #include <osl/thread.h>
 #include "securityenvironment_mscryptimpl.hxx"
 
-#ifndef _X509CERTIFICATE_NSSIMPL_HXX_
 #include "x509certificate_mscryptimpl.hxx"
-#endif
 #include <rtl/uuid.h>
 
 #include <xmlsec/xmlsec.h>
@@ -1310,3 +1309,5 @@ void SecurityEnvironment_MSCryptImpl :: destroyKeysManager(xmlSecKeysMngrPtr pKe
         xmlSecKeysMngrDestroy( pKeysMngr ) ;
     }
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
